# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.4.0

([Full Changelog](https://github.com/jupyterlite/xeus-python-kernel/compare/v0.3.0...0da0c11690c0d065c2f33b63d88064aec0b79529))

### Enhancements made

- Update jupyterlite and enable file-system access [#27](https://github.com/jupyterlite/xeus-python-kernel/pull/27) ([@martinRenou](https://github.com/martinRenou))
- Fix conflicts with sys prefix packages and ignore ignore_sys_prefix flag [#23](https://github.com/jupyterlite/xeus-python-kernel/pull/23) ([@martinRenou](https://github.com/martinRenou))
- Toplevel await [#25](https://github.com/jupyterlite/xeus-python-kernel/pull/25) ([@DerThorsten](https://github.com/DerThorsten))
- Make xeus-python version configurable [#24](https://github.com/jupyterlite/xeus-python-kernel/pull/24) ([@martinRenou](https://github.com/martinRenou))
- Fix hanging jupyterlite build via jupyterlite-sphinx [#21](https://github.com/jupyterlite/xeus-python-kernel/pull/21) ([@benbovy](https://github.com/benbovy))

### Documentation improvements

- Improve docs [#28](https://github.com/jupyterlite/xeus-python-kernel/pull/28) ([@martinRenou](https://github.com/martinRenou))
- Update docs using 0.3.0 [#19](https://github.com/jupyterlite/xeus-python-kernel/pull/19) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-python-kernel/graphs/contributors?from=2022-05-24&to=2022-06-20&type=c))

[@benbovy](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3Abenbovy+updated%3A2022-05-24..2022-06-20&type=Issues) | [@bollwyvl](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3Abollwyvl+updated%3A2022-05-24..2022-06-20&type=Issues) | [@davidbrochart](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3Adavidbrochart+updated%3A2022-05-24..2022-06-20&type=Issues) | [@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3ADerThorsten+updated%3A2022-05-24..2022-06-20&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3AmartinRenou+updated%3A2022-05-24..2022-06-20&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.3.0

([Full Changelog](https://github.com/jupyterlite/xeus-python-kernel/compare/8166fc63fd8b4f56b39431e810dabbeae842ea83...280c7c60b77d19a161de8256ccda7b77235f5690))

### Merged PRs

- Reduce sdist size [#17](https://github.com/jupyterlite/xeus-python-kernel/pull/17) ([@martinRenou](https://github.com/martinRenou))
- Update emsdk and empack [#16](https://github.com/jupyterlite/xeus-python-kernel/pull/16) ([@martinRenou](https://github.com/martinRenou))
- Remove duplication of the labextension [#15](https://github.com/jupyterlite/xeus-python-kernel/pull/15) ([@martinRenou](https://github.com/martinRenou))
- Rebuild with latest empack [#13](https://github.com/jupyterlite/xeus-python-kernel/pull/13) ([@martinRenou](https://github.com/martinRenou))
- Add back Changelog [#11](https://github.com/jupyterlite/xeus-python-kernel/pull/11) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-python-kernel/graphs/contributors?from=2022-05-19&to=2022-05-24&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3Ajtpio+updated%3A2022-05-19..2022-05-24&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3AmartinRenou+updated%3A2022-05-19..2022-05-24&type=Issues)

## v0.2.0

### What's Changed

- Add docs by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/4
- Fix build by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/5
- Add Matplotlib to the env by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/7
- Do not use xeus-python's master branch by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/8
- Simplify dockerfile by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/9
- Xeus python build addon by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/10

**Full Changelog**: https://github.com/jupyterlite/xeus-python-kernel/compare/0.1.0...0.2.0

## v0.1.0

### Contributions

- Initial version by @DerThorsten in https://github.com/jupyterlite/xeus-python-kernel/commit/d28dbc1ec9c1dca3f861d79ee5930054c00d5998
- Remove sleep + renames according to https://github.com/jupyter-xeus/xeus-python/pull/530 by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/1
- Fix README by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/2
- Add Docker build by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/3

### Contributors

- @DerThorsten started the project
- @martinRenou made their first contribution in https://github.com/jupyterlite/xeus-python-kernel/pull/1

**Full Changelog**: https://github.com/jupyterlite/xeus-python-kernel/commits/0.1.0
